X-Git-Url: https://git.rapsys.eu/airbundle/blobdiff_plain/695a92febd4483f92fb8520bee1451317df8510f..bc28bb466c3b8f25bdee997270890297d6086a00:/Controller/ApplicationController.php?ds=inline

diff --git a/Controller/ApplicationController.php b/Controller/ApplicationController.php
index 625e7f8..deab095 100644
--- a/Controller/ApplicationController.php
+++ b/Controller/ApplicationController.php
@@ -125,21 +125,24 @@ class ApplicationController extends DefaultController {
 					$session->setLength(new \DateTime('05:00:00'));
 				//Check if afternoon
 				} elseif ($slot == 'Afternoon') {
-					//Set begin at 14h
-					$session->setBegin(new \DateTime('14:30:00'));
+					//Set begin at 16h
+					$session->setBegin(new \DateTime('16:00:00'));
 
-					//Set length at 5h
-					$session->setLength(new \DateTime('04:30:00'));
+					//Set length at 3h
+					$session->setLength(new \DateTime('03:00:00'));
 				//Check if evening
 				} elseif ($slot == 'Evening') {
-					//Set begin at 19h
-					$session->setBegin(new \DateTime('19:00:00'));
+					//Set begin at 20h30
+					$session->setBegin(new \DateTime('20:30:00'));
 
 					//Check if next day is premium
 					if ($premium) {
 						//Set length at 7h
 						$session->setLength(new \DateTime('07:00:00'));
 					}
+
+					//Set length at 4h
+					$session->setLength(new \DateTime('04:30:00'));
 				//Check if after
 				} else {
 					//Set begin at 1h
@@ -414,7 +417,7 @@ class ApplicationController extends DefaultController {
 				//Generate url
 				return $this->redirectToRoute($name, $route);
 			//No route matched
-			} catch(MethodNotAllowedException|ResourceNotFoundException $e) {
+			} catch (MethodNotAllowedException|ResourceNotFoundException $e) {
 				//Unset referer to fallback to default route
 				unset($referer);
 			}